Introduction — NeuroLab 0.3.4 documentation

### Navigation

- index
- next |
- previous |
- NeuroLab 0.3.4 documentation »

# Introduction

# Support neural networks types

> Single layer perceptron
>   - create function: neurolab.net.newp()
>   - example of use: newp
>   - default train function: neurolab.train.train_delta()
>   - support train functions: train_gd, train_gda, train_gdm, train_gdx, train_rprop, train_bfgs, train_cg
> Multilayer feed forward perceptron
>   - create function: neurolab.net.newff()
>   - example of use: newff
>   - default train function: neurolab.train.train_gdx()
>   - support train functions: train_gd, train_gda, train_gdm, train_rprop, train_bfgs, train_cg
> Competing layer (Kohonen Layer)
>   - create function: neurolab.net.newc()
>   - example of use: newc
>   - default train function: neurolab.train.train_cwta()
>   - support train functions: train_wta
> Learning Vector Quantization (LVQ)
>   - create function: neurolab.net.newlvq()
>   - example of use: newlvq
>   - default train function: neurolab.train.train_lvq()
> Elman Recurrent network
>   - create function: neurolab.net.newelm()
>   - example of use: newelm
>   - default train function: neurolab.train.train_gdx()
>   - support train functions: train_gd, train_gda, train_gdm, train_rprop, train_bfgs, train_cg
> Hopfield Recurrent network
>   - create function: neurolab.net.newhop()
>   - example of use: newhop
> Hemming Recurrent network
>   - create function: neurolab.net.newhem()
>   - example of use: newhem

### Navigation

- index
- next |
- previous |
- NeuroLab 0.3.4 documentation »